***********
Conventions
***********
The following formatting conventions are used throughout this guide:

* *Italic* - Used for commands, filenames, directories, script variables, keywords, emphasis, technical terms, and Internet domain names
